@@ -1,8 +1,10 @@
 __author__ = 'ardevelop'
 
+import os
 import json
 import datetime
 import subprocess
+import errno
 
 import yaml
 import tornado.web
@@ -60,9 +62,24 @@ class Processor(object):
         self.application.ioloop.add_timeout(self.application.interval, self.application.next)
 
     def wait(self):
-        print "wait"
-        return_code = self.process.wait(1)
-        print "wait done", return_code
+        try:
+            pid, sts = subprocess._eintr_retry_call(os.waitpid, self.process.pid, 0)
+        except OSError as e:
+            if e.errno != errno.ECHILD:
+                raise
+
+            pid = self.process.pid
+            sts = 0
+
+        if pid == self.process.pid:
+            try:
+                self.process._handle_exitstatus(sts)
+            except RuntimeError:
+                pass
+
+        return_code = self.process.returncode
+
+        print "wait", return_code
         if return_code is None:
             self.application.ioloop.add_timeout(self.application.interval, self.wait)
         elif return_code == 0:
